==> Paws-0.29.tar.gz: Paws-0.29/lib/Paws/SQS/BatchResultErrorEntry.pm <==
package Paws::SQS::BatchResultErrorEntry;
  use Moose;
  has Code => (is => 'ro', isa => 'Str', required => 1);
  has Id => (is => 'ro', isa => 'Str', required => 1);
  has Message => (is => 'ro', isa => 'Str');
  has SenderFault => (is => 'ro', isa => 'Bool', required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::SQS::BatchResultErrorEntry

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SQS::BatchResultErrorEntry object:

  $service_obj->Method(Att1 => { Code => $value, ..., SenderFault => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SQS::BatchResultErrorEntry object:

  $result = $service_obj->Method(...);
  $result->Att1->Code

=head1 DESCRIPTION

This is used in the responses of batch API to give a detailed
description of the result of an action on each entry in the request.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Code => Str

  An error code representing why the action failed on this entry.


=head2 B<REQUIRED> Id => Str

  The C<Id> of an entry in a batch request.


=head2 Message => Str

  A message explaining why the action failed on this entry.


=head2 B<REQUIRED> SenderFault => Bool

  Specifies whether the error happened due to the sender's fault.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SQS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/SQS/BatchResultErrorEntry.pm <==
package Paws::SQS::BatchResultErrorEntry;
  use Moose;
  has Code => (is => 'ro', isa => 'Str', required => 1);
  has Id => (is => 'ro', isa => 'Str', required => 1);
  has Message => (is => 'ro', isa => 'Str');
  has SenderFault => (is => 'ro', isa => 'Bool', required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::SQS::BatchResultErrorEntry

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SQS::BatchResultErrorEntry object:

  $service_obj->Method(Att1 => { Code => $value, ..., SenderFault => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SQS::BatchResultErrorEntry object:

  $result = $service_obj->Method(...);
  $result->Att1->Code

=head1 DESCRIPTION

This is used in the responses of batch API to give a detailed
description of the result of an action on each entry in the request.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Code => Str

  An error code representing why the action failed on this entry.


=head2 B<REQUIRED> Id => Str

  The C<Id> of an entry in a batch request.


=head2 Message => Str

  A message explaining why the action failed on this entry.


=head2 B<REQUIRED> SenderFault => Bool

  Specifies whether the error happened due to the sender's fault.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SQS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
